<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>OutputPulseAudioFactory</name>
    <message>
        <location filename="../outputpulseaudiofactory.cpp" line="30"/>
        <source>PulseAudio Plugin</source>
        <translation>Модуль PulseAudio</translation>
    </message>
    <message>
        <location filename="../outputpulseaudiofactory.cpp" line="54"/>
        <source>About PulseAudio Output Plugin</source>
        <translation>О модуле вывода PulseAudio</translation>
    </message>
    <message>
        <location filename="../outputpulseaudiofactory.cpp" line="55"/>
        <source>Qmmp PulseAudio Output Plugin</source>
        <translation>Модуль вывода PulseAudio для Qmmp</translation>
    </message>
    <message>
        <location filename="../outputpulseaudiofactory.cpp" line="56"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
